@@ -1,7 +1,7 @@
 #
 # atimer - timer library for asyncio
 # 
-# Copyright (C) 2016-2019 by Artur Wroblewski <wrobell@riseup.net>
+# Copyright (C) 2016-2021 by Artur Wroblewski <wrobell@riseup.net>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,8 +17,25 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
+"""
+`atimer` library implements asynchronous timer Python coroutine based on
+POSIX timers. The coroutine can be used with Python `asyncio
+<https://docs.python.org/3/library/asyncio.html>`_ module API.
+
+The main features are
+
+- timer expires at regular intervals
+- track number of expirations if a long running task causes overrun
+- start synchronized with system clock at the edge of an interval
+- measure time while system is suspended
+"""
+
+import pkg_resources
+
 from .glue import Timer
 
-__version__ = '0.3.3'
+__version__ = pkg_resources.get_distribution('atimer').version
+
+__all__ = ['Timer']
 
 # vim: sw=4:et:ai
